@@ -1,7 +1,7 @@
 from pydantic import BaseModel, Field
-from typing import Annotated, Literal, Optional, TypeVar, Union, overload
+from typing import Annotated, Literal, TypeVar, overload
 from maleo.enums.expiration import Expiration
-from maleo.types.string import OptionalString
+from maleo.types.string import OptStr
 from ..enums import CacheOrigin, CacheLayer
 from ..utils import build_cache_namespace
 
@@ -10,12 +10,13 @@ class BaseAdditionalConfig(BaseModel):
     """Base additional configuration class for database."""
 
 
-AdditionalConfigT = TypeVar("AdditionalConfigT", bound=Optional[BaseAdditionalConfig])
+OptBaseAdditionalConfig = BaseAdditionalConfig | None
+AdditionalConfigT = TypeVar("AdditionalConfigT", bound=OptBaseAdditionalConfig)
 
 
 class RedisAdditionalConfig(BaseAdditionalConfig):
     ttl: Annotated[
-        Union[float, int, Expiration],
+        float | int | Expiration,
         Field(Expiration.EXP_15MN.value, description="Time to live"),
     ] = Expiration.EXP_15MN.value
     base_namespace: Annotated[str, Field(..., description="Base namespace")]
@@ -25,7 +26,7 @@ class RedisAdditionalConfig(BaseAdditionalConfig):
         self,
         *ext: str,
         use_self_base: Literal[False],
-        base: OptionalString = None,
+        base: OptStr = None,
         origin: Literal[CacheOrigin.SERVICE],
         layer: CacheLayer,
         sep: str = ":",
@@ -35,7 +36,7 @@ class RedisAdditionalConfig(BaseAdditionalConfig):
         self,
         *ext: str,
         use_self_base: Literal[False],
-        base: OptionalString = None,
+        base: OptStr = None,
         client: str,
         origin: Literal[CacheOrigin.CLIENT],
         layer: CacheLayer,
@@ -64,8 +65,8 @@ class RedisAdditionalConfig(BaseAdditionalConfig):
         self,
         *ext: str,
         use_self_base: bool = True,
-        base: OptionalString = None,
-        client: OptionalString = None,
+        base: OptStr = None,
+        client: OptStr = None,
         origin: CacheOrigin,
         layer: CacheLayer,
         sep: str = ":",
