@@ -1,30 +1,31 @@
 from abc import ABC, abstractmethod
 from pydantic import BaseModel, Field, model_validator
-from typing import Annotated, Generic, Literal, Optional, TypeVar
+from typing import Annotated, Generic, Literal, TypeVar
 from urllib.parse import quote_plus, urlencode
-from maleo.types.boolean import OptionalBoolean
+from maleo.types.boolean import OptBool
 from maleo.types.dict import (
-    OptionalStringToAnyDict,
-    StringToAnyDict,
-    StringToStringDict,
+    OptStrToAnyDict,
+    StrToAnyDict,
+    StrToStrDict,
 )
-from maleo.types.integer import OptionalInteger
-from maleo.types.string import OptionalString
+from maleo.types.integer import OptInt
+from maleo.types.string import OptStr
 from ..enums import (
     Connection,
     Driver,
-    PostgreSQLSSLMode,
+    OptPostgreSQLSSLMode,
     MySQLCharset,
     MongoReadPreference,
+    OptMongoReadPreference,
     ElasticsearchScheme,
 )
 
 
 DriverT = TypeVar("DriverT", bound=Driver)
-UsernameT = TypeVar("UsernameT", bound=OptionalString)
-PasswordT = TypeVar("PasswordT", bound=OptionalString)
-HostT = TypeVar("HostT", bound=OptionalString)
-PortT = TypeVar("PortT", bound=OptionalInteger)
+UsernameT = TypeVar("UsernameT", bound=OptStr)
+PasswordT = TypeVar("PasswordT", bound=OptStr)
+HostT = TypeVar("HostT", bound=OptStr)
+PortT = TypeVar("PortT", bound=OptInt)
 DatabaseT = TypeVar("DatabaseT", int, str)
 
 
@@ -41,11 +42,9 @@ class BaseConnectionConfig(
     database: DatabaseT = Field(..., description="Database's name")
 
     # Optional fields for different database types
-    ssl: Annotated[
-        OptionalBoolean, Field(None, description="Enable SSL connection")
-    ] = None
+    ssl: Annotated[OptBool, Field(None, description="Enable SSL connection")] = None
     options: Annotated[
-        OptionalStringToAnyDict,
+        OptStrToAnyDict,
         Field(None, description="Additional connection options"),
     ] = None
 
@@ -75,15 +74,13 @@ class BaseConnectionConfig(
 
         return self
 
-    def _safe_encode_credential(self, credential: OptionalString) -> str:
+    def _safe_encode_credential(self, credential: OptStr) -> str:
         """Safely URL-encode credentials to handle special characters."""
         return quote_plus(credential) if credential else ""
 
-    def _make_options_string(
-        self, additional_options: OptionalStringToAnyDict = None
-    ) -> str:
+    def _make_options_string(self, additional_options: OptStrToAnyDict = None) -> str:
         """Build URL query string from options, removing null values."""
-        all_options: StringToAnyDict = dict(self.options) if self.options else {}
+        all_options: StrToAnyDict = dict(self.options) if self.options else {}
         if additional_options:
             all_options.update(additional_options)
 
@@ -121,7 +118,7 @@ class BaseConnectionConfig(
     def _make_url(self, connection: Connection = Connection.ASYNC) -> str:
         """URL Maker for specific database's type"""
 
-    def get_driver_variants(self) -> StringToStringDict:
+    def get_driver_variants(self) -> StrToStrDict:
         """Get available driver variants for this database type."""
         variants = {}
 
@@ -204,18 +201,16 @@ class BaseConnectionConfig(
 
 
 class ElasticsearchConnectionConfig(
-    BaseConnectionConfig[
-        Literal[Driver.ELASTICSEARCH], OptionalString, OptionalString, str, int, str
-    ]
+    BaseConnectionConfig[Literal[Driver.ELASTICSEARCH], OptStr, OptStr, str, int, str]
 ):
     driver: Literal[Driver.ELASTICSEARCH] = Driver.ELASTICSEARCH
     port: Annotated[int, Field(9200, description="Elasticsearch port")] = 9200
-    username: Annotated[
-        OptionalString, Field(None, description="Elasticsearch username")
-    ] = None
-    password: Annotated[
-        OptionalString, Field(None, description="Elasticsearch password")
-    ] = None
+    username: Annotated[OptStr, Field(None, description="Elasticsearch username")] = (
+        None
+    )
+    password: Annotated[OptStr, Field(None, description="Elasticsearch password")] = (
+        None
+    )
     database: Annotated[
         str, Field("_all", description="Elasticsearch index pattern")
     ] = "_all"
@@ -255,30 +250,22 @@ class ElasticsearchConnectionConfig(
 
 
 class MongoConnectionConfig(
-    BaseConnectionConfig[
-        Literal[Driver.MONGODB], OptionalString, OptionalString, str, int, str
-    ]
+    BaseConnectionConfig[Literal[Driver.MONGODB], OptStr, OptStr, str, int, str]
 ):
     driver: Literal[Driver.MONGODB] = Driver.MONGODB
     port: Annotated[int, Field(27017, description="Mongo port")] = 27017
-    username: Annotated[OptionalString, Field(None, description="Mongo username")] = (
-        None
-    )
-    password: Annotated[OptionalString, Field(None, description="Mongo password")] = (
-        None
-    )
+    username: Annotated[OptStr, Field(None, description="Mongo username")] = None
+    password: Annotated[OptStr, Field(None, description="Mongo password")] = None
 
     # Mongo-specific options
     auth_source: Annotated[
-        OptionalString, Field("admin", description="Authentication database")
+        OptStr, Field("admin", description="Authentication database")
     ] = "admin"
     read_preference: Annotated[
-        Optional[MongoReadPreference],
+        OptMongoReadPreference,
         Field(MongoReadPreference.PRIMARY, description="Read preference"),
     ] = MongoReadPreference.PRIMARY
-    replica_set: Annotated[
-        OptionalString, Field(None, description="Replica set name")
-    ] = None
+    replica_set: Annotated[OptStr, Field(None, description="Replica set name")] = None
 
     @model_validator(mode="after")
     def validate_auth_consistency(self):
@@ -313,9 +300,7 @@ class MongoConnectionConfig(
 
 
 class RedisConnectionConfig(
-    BaseConnectionConfig[
-        Literal[Driver.REDIS], OptionalString, OptionalString, str, int, int
-    ]
+    BaseConnectionConfig[Literal[Driver.REDIS], OptStr, OptStr, str, int, int]
 ):
     driver: Literal[Driver.REDIS] = Driver.REDIS
     port: Annotated[int, Field(6379, description="Redis port")] = 6379
@@ -323,18 +308,16 @@ class RedisConnectionConfig(
         int, Field(0, description="Redis database number (0-15)", ge=0, le=15)
     ] = 0
     username: Annotated[
-        OptionalString, Field(None, description="Redis username (Redis 6+)")
+        OptStr, Field(None, description="Redis username (Redis 6+)")
     ] = None
-    password: Annotated[OptionalString, Field(None, description="Redis password")] = (
-        None
-    )
+    password: Annotated[OptStr, Field(None, description="Redis password")] = None
 
     # Redis-specific options
     decode_responses: Annotated[
         bool, Field(True, description="Decode responses to strings")
     ] = True
     max_connections: Annotated[
-        OptionalInteger, Field(None, ge=1, description="Max connections in pool")
+        OptInt, Field(None, ge=1, description="Max connections in pool")
     ] = None
 
     def _make_url(self, connection: Connection = Connection.ASYNC) -> str:
@@ -393,7 +376,7 @@ class MySQLConnectionConfig(
         return base_url + self._make_options_string(mysql_options)
 
     @property
-    def engine_kwargs(self) -> StringToAnyDict:
+    def engine_kwargs(self) -> StrToAnyDict:
         return self.model_dump(include={"echo"}, exclude_none=True)
 
 
@@ -410,11 +393,9 @@ class PostgreSQLConnectionConfig(
     echo: Annotated[bool, Field(False, description="Enable SQL statement logging")] = (
         False
     )
-    sslmode: Annotated[
-        Optional[PostgreSQLSSLMode], Field(None, description="SSL mode")
-    ] = None
+    sslmode: Annotated[OptPostgreSQLSSLMode, Field(None, description="SSL mode")] = None
     application_name: Annotated[
-        OptionalString,
+        OptStr,
         Field(None, description="Application name for connection tracking"),
     ] = None
 
@@ -442,7 +423,7 @@ class PostgreSQLConnectionConfig(
         return base_url + self._make_options_string(pg_options)
 
     @property
-    def engine_kwargs(self) -> StringToAnyDict:
+    def engine_kwargs(self) -> StrToAnyDict:
         return self.model_dump(include={"echo"}, exclude_none=True)
 
 
@@ -479,7 +460,7 @@ class SQLiteConnectionConfig(
         return base_url + self._make_options_string()
 
     @property
-    def engine_kwargs(self) -> StringToAnyDict:
+    def engine_kwargs(self) -> StrToAnyDict:
         return self.model_dump(include={"echo"}, exclude_none=True)
 
 
@@ -540,7 +521,7 @@ class SQLServerConnectionConfig(
         return base_url + self._make_options_string(mssql_options)
 
     @property
-    def engine_kwargs(self) -> StringToAnyDict:
+    def engine_kwargs(self) -> StrToAnyDict:
         return self.model_dump(include={"echo"}, exclude_none=True)
 
 
