@@ -16,15 +16,14 @@ from typing import (
     Generic,
     Literal,
     Tuple,
-    Union,
     overload,
 )
 from uuid import uuid4
 from maleo.logging.enums import Level
 from maleo.logging.logger import EnvironmentT, ServiceKeyT, Database
-from maleo.schemas.application import ApplicationContext, OptionalApplicationContext
-from maleo.schemas.connection import OptionalConnectionContext
-from maleo.schemas.error.enums import Code as ErrorCode
+from maleo.schemas.application import ApplicationContext, OptApplicationContext
+from maleo.schemas.connection import OptConnectionContext
+from maleo.schemas.error.enums import ErrorCode
 from maleo.schemas.exception.exc import MaleoException
 from maleo.schemas.exception.factory import Factory as MaleoExceptionFactory
 from maleo.schemas.operation.action.system import SystemOperationAction
@@ -39,10 +38,10 @@ from maleo.schemas.operation.enums import (
 from maleo.schemas.operation.mixins import Timestamp
 from maleo.schemas.operation.system import SuccessfulSystemOperation
 from maleo.schemas.response import NoDataResponse
-from maleo.schemas.security.authentication import OptionalAnyAuthentication
-from maleo.schemas.security.authorization import OptionalAnyAuthorization
-from maleo.schemas.security.impersonation import OptionalImpersonation
-from maleo.types.uuid import OptionalUUID
+from maleo.schemas.security.authentication import OptAnyAuthentication
+from maleo.schemas.security.authorization import OptAnyAuthorization
+from maleo.schemas.security.impersonation import OptImpersonation
+from maleo.types.uuid import OptUUID
 from maleo.utils.exception import extract_details
 from ..enums import Connection
 from ..config import SQLConfigT
@@ -54,7 +53,7 @@ class SessionManager(Generic[SQLConfigT]):
         config: SQLConfigT,
         engines: Tuple[AsyncEngine, Engine],
         logger: Database[EnvironmentT, ServiceKeyT],
-        application_context: OptionalApplicationContext = None,
+        application_context: OptApplicationContext = None,
     ):
         self._config = config
         self._async_engine, self._sync_engine = engines
@@ -82,11 +81,11 @@ class SessionManager(Generic[SQLConfigT]):
 
     async def _async_session_handler(
         self,
-        operation_id: OptionalUUID = None,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
+        operation_id: OptUUID = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
     ) -> AsyncGenerator[AsyncSession, None]:
         """Reusable function for managing async database session."""
         operation_id = operation_id if operation_id is not None else uuid4()
@@ -206,11 +205,11 @@ class SessionManager(Generic[SQLConfigT]):
 
     def _sync_session_handler(
         self,
-        operation_id: OptionalUUID = None,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
+        operation_id: OptUUID = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
     ) -> Generator[Session, None, None]:
         """Reusable function for managing sync database session."""
         operation_id = operation_id if operation_id is not None else uuid4()
@@ -331,11 +330,11 @@ class SessionManager(Generic[SQLConfigT]):
     @asynccontextmanager
     async def _async_context_manager(
         self,
-        operation_id: OptionalUUID = None,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
+        operation_id: OptUUID = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
     ) -> AsyncGenerator[AsyncSession, None]:
         """Async context manager implementation."""
         async for session in self._async_session_handler(
@@ -350,11 +349,11 @@ class SessionManager(Generic[SQLConfigT]):
     @contextmanager
     def _sync_context_manager(
         self,
-        operation_id: OptionalUUID = None,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
+        operation_id: OptUUID = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
     ) -> Generator[Session, None, None]:
         """Sync context manager implementation."""
         yield from self._sync_session_handler(
@@ -370,35 +369,33 @@ class SessionManager(Generic[SQLConfigT]):
     def get(
         self,
         connection: Literal[Connection.ASYNC],
-        operation_id: OptionalUUID = None,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
+        operation_id: OptUUID = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
     ) -> AbstractAsyncContextManager[AsyncSession]: ...
 
     @overload
     def get(
         self,
         connection: Literal[Connection.SYNC],
-        operation_id: OptionalUUID = None,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
+        operation_id: OptUUID = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
     ) -> AbstractContextManager[Session]: ...
 
     def get(
         self,
         connection: Connection = Connection.ASYNC,
-        operation_id: OptionalUUID = None,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
-    ) -> Union[
-        AbstractAsyncContextManager[AsyncSession], AbstractContextManager[Session]
-    ]:
+        operation_id: OptUUID = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
+    ) -> AbstractAsyncContextManager[AsyncSession] | AbstractContextManager[Session]:
         """Context manager for manual session handling."""
         if operation_id is None:
             operation_id = uuid4()
@@ -423,11 +420,11 @@ class SessionManager(Generic[SQLConfigT]):
     @asynccontextmanager
     async def get_async(
         self,
-        operation_id: OptionalUUID = None,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
+        operation_id: OptUUID = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
     ) -> AsyncGenerator[AsyncSession, None]:
         """Explicit async context manager."""
         async for session in self._async_session_handler(
@@ -440,11 +437,11 @@ class SessionManager(Generic[SQLConfigT]):
     @contextmanager
     def get_sync(
         self,
-        operation_id: OptionalUUID = None,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
+        operation_id: OptUUID = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
     ) -> Generator[Session, None, None]:
         """Explicit sync context manager."""
         yield from self._sync_session_handler(
@@ -455,11 +452,11 @@ class SessionManager(Generic[SQLConfigT]):
 
     def as_async_dependency(
         self,
-        operation_id: OptionalUUID = None,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
+        operation_id: OptUUID = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
     ):
         """Explicit async dependency injection."""
 
@@ -476,11 +473,11 @@ class SessionManager(Generic[SQLConfigT]):
 
     def as_sync_dependency(
         self,
-        operation_id: OptionalUUID = None,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
+        operation_id: OptUUID = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
     ):
         """Explicit sync dependency injection."""
 
